pub struct WgpuAtlas(/* private fields */);Implementations
Sourceimpl WgpuAtlas
impl WgpuAtlas
pub fn new( device: Arc<Device>, queue: Arc<Queue>, color_texture_format: TextureFormat, ) -> Self
pub fn from_context(context: &WgpuContext) -> Self
pub fn before_frame(&self)
pub fn get_texture_info(&self, id: AtlasTextureId) -> WgpuTextureInfo
Sourcepub fn clear(&self)
pub fn clear(&self)
Clears all cached textures and tiles, forcing them to be recreated. Use this for incremental recovery when the device is still valid.
Sourcepub fn handle_device_lost(&self, context: &WgpuContext)
pub fn handle_device_lost(&self, context: &WgpuContext)
Handles device lost by clearing all textures and cached tiles. The atlas will lazily recreate textures as needed on subsequent frames.